/********************************************************
  Check PIR output
  This function checks for motion, and increments a variable "PIRDuration" to reflect 
  the total time of motion, as well as "PIRCount" to reflect the total number of motion
  "bouts" detected.  A "bout" is initiated whenever motion is detected, and is ended
  when motion is absent for 0.6s.

  This function performs two additional tasks.  It checks the battery level, and also
  allows monitors the "C", button, which displays elapsed time when pushed.
********************************************************/
void  CheckPIR() {
  ReadBatteryLevel();  //Read battery level

  // Monitor PIR
  while (digitalRead (PIR_PIN) == HIGH) {  // if PIR active
    PIRDuration += PIRcalibration;  //calibrated with stopwatch, it was more accurate than using millis() to time this
    PIRDurationChange += PIRcalibration;
    PIRActive = true;
  }

  for (int i = 0; i <= PIRBoutDuration; i++) { // If PIR is low for 0.6s count it as the end of a locomotion bout
    delay (1);
    if (digitalRead (PIR_PIN) == HIGH) {
      i = 0;
      break;
    }
    if (PIRActive == true & i == PIRBoutDuration) {
      PIRCount++;
      PIRCountChange++;
      PIRActive = false;
    }
  }

  // Show time elapsed when C is pressed
  calcTimeElapsed();
  while (digitalRead (buttonC) == LOW) {
    DisplayTimeElapsed();
  }
}
