/********************************************************
  RAD (Rodent Activity Detector)
  Written by REDACTED FOR BLIND PEER REVIEW
  March 11, 2019

  This code is used to control a passive-infrared (PIR) sensor-based device for monitoring
  home-cage activity of rodents. This device detects movement and logs data every minute to a microSD card. 
  The device is wireless and battery powered, and can record data for about 3 weeks on a charge.  

  The default logging frequency is once per minute.  If you want to change this change the variable
  called logfreq on line 48 of "a_header.h"
    
  Full device design files and description are here:
  https://hackaday.io/project/160742-homecage-activity-monitoring-with-pirs
  
  This project code includes code from:
  *** Adafruit, who made the hardware breakout boards and associated code ***

  Cavemoa's excellent examples of datalogging with the Adalogger:
  https://github.com/cavemoa/Feather-M0-Adalogger

  Uses Arduino Time library http://playground.arduino.cc/code/time
  Maintained by Paul Stoffregen https://github.com/PaulStoffregen/Time

  Uses Arduino Zero RTC library https://www.arduino.cc/en/Reference/RTC
  Maintained by Arturo Guadalupi https://github.com/arduino-libraries/RTCZero

  Uses Pong game code from Matt Watson available here:
  https://www.hackster.io/mwatson/world-s-smallest-pong-a45ea9
  
  This project is released under the terms of the Creative Commons - Attribution - ShareAlike 3.0 license:
  human readable: https://creativecommons.org/licenses/by-sa/3.0/
  legal wording: https://creativecommons.org/licenses/by-sa/3.0/legalcode
  Copyright (c) 2019 Lex Kravitz
  ********************************************************/

/********************************************************
  Setup code
  This setup code adds libraries and other setup variables contained
  in "a_header.h". Do not alter these lines here.
********************************************************/
#include "a_Header.h" //See "a_header.h" for #defines and other constants 

void setup() {
  StartUpCommands();
}

/********************************************************
  Main loop
  This is the main loop of the code. You can edit the functions:
  UpdateDisplay(): to alter what is displayed on the screen
  CheckPIR(): to alter how the device checks for motion
  LogData(): to alter what is written to the SD card
********************************************************/
void loop() {
  UpdateDisplay();
  CheckPIR();
  LogData();
}
